==> zio-aws-forecast_2.13-5.19.8.2-sources.jar: zio/aws/forecast/model/ListDatasetImportJobsResponse.scala <==
package zio.aws.forecast.model
import zio.ZIO
import zio.aws.forecast.model.primitives.NextToken
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class ListDatasetImportJobsResponse(
    datasetImportJobs: Optional[
      Iterable[zio.aws.forecast.model.DatasetImportJobSummary]
    ] = Optional.Absent,
    nextToken: Optional[NextToken] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.forecast.model.ListDatasetImportJobsResponse = {
    import ListDatasetImportJobsResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.forecast.model.ListDatasetImportJobsResponse
      .builder()
      .optionallyWith(
        datasetImportJobs.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.datasetImportJobs)
      .optionallyWith(
        nextToken.map(value => NextToken.unwrap(value): java.lang.String)
      )(_.nextToken)
      .build()
  }
  def asReadOnly
      : zio.aws.forecast.model.ListDatasetImportJobsResponse.ReadOnly =
    zio.aws.forecast.model.ListDatasetImportJobsResponse.wrap(buildAwsValue())
}
object ListDatasetImportJobsResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.forecast.model.ListDatasetImportJobsResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.forecast.model.ListDatasetImportJobsResponse =
      zio.aws.forecast.model.ListDatasetImportJobsResponse(
        datasetImportJobs.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        nextToken.map(value => value)
      )
    def datasetImportJobs: Optional[
      List[zio.aws.forecast.model.DatasetImportJobSummary.ReadOnly]
    ]
    def nextToken: Optional[NextToken]
    def getDatasetImportJobs: ZIO[Any, AwsError, List[
      zio.aws.forecast.model.DatasetImportJobSummary.ReadOnly
    ]] = AwsError.unwrapOptionField("datasetImportJobs", datasetImportJobs)
    def getNextToken: ZIO[Any, AwsError, NextToken] =
      AwsError.unwrapOptionField("nextToken", nextToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.forecast.model.ListDatasetImportJobsResponse
  ) extends zio.aws.forecast.model.ListDatasetImportJobsResponse.ReadOnly {
    override val datasetImportJobs: Optional[
      List[zio.aws.forecast.model.DatasetImportJobSummary.ReadOnly]
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.datasetImportJobs())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.forecast.model.DatasetImportJobSummary.wrap(item)
        }.toList
      )
    override val nextToken: Optional[NextToken] = zio.aws.core.internal
      .optionalFromNullable(impl.nextToken())
      .map(value => zio.aws.forecast.model.primitives.NextToken(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.forecast.model.ListDatasetImportJobsResponse
  ): zio.aws.forecast.model.ListDatasetImportJobsResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-forecast_3-5.17.186.1-sources.jar: zio/aws/forecast/model/ListDatasetImportJobsResponse.scala <==
package zio.aws.forecast.model
import zio.ZIO
import zio.aws.forecast.model.primitives.NextToken
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class ListDatasetImportJobsResponse(
    datasetImportJobs: Optional[
      Iterable[zio.aws.forecast.model.DatasetImportJobSummary]
    ] = Optional.Absent,
    nextToken: Optional[NextToken] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.forecast.model.ListDatasetImportJobsResponse = {
    import ListDatasetImportJobsResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.forecast.model.ListDatasetImportJobsResponse
      .builder()
      .optionallyWith(
        datasetImportJobs.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.datasetImportJobs)
      .optionallyWith(
        nextToken.map(value => NextToken.unwrap(value): java.lang.String)
      )(_.nextToken)
      .build()
  }
  def asReadOnly
      : zio.aws.forecast.model.ListDatasetImportJobsResponse.ReadOnly =
    zio.aws.forecast.model.ListDatasetImportJobsResponse.wrap(buildAwsValue())
}
object ListDatasetImportJobsResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.forecast.model.ListDatasetImportJobsResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.forecast.model.ListDatasetImportJobsResponse =
      zio.aws.forecast.model.ListDatasetImportJobsResponse(
        datasetImportJobs.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        nextToken.map(value => value)
      )
    def datasetImportJobs: Optional[
      List[zio.aws.forecast.model.DatasetImportJobSummary.ReadOnly]
    ]
    def nextToken: Optional[NextToken]
    def getDatasetImportJobs: ZIO[Any, AwsError, List[
      zio.aws.forecast.model.DatasetImportJobSummary.ReadOnly
    ]] = AwsError.unwrapOptionField("datasetImportJobs", datasetImportJobs)
    def getNextToken: ZIO[Any, AwsError, NextToken] =
      AwsError.unwrapOptionField("nextToken", nextToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.forecast.model.ListDatasetImportJobsResponse
  ) extends zio.aws.forecast.model.ListDatasetImportJobsResponse.ReadOnly {
    override val datasetImportJobs: Optional[
      List[zio.aws.forecast.model.DatasetImportJobSummary.ReadOnly]
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.datasetImportJobs())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.forecast.model.DatasetImportJobSummary.wrap(item)
        }.toList
      )
    override val nextToken: Optional[NextToken] = zio.aws.core.internal
      .optionalFromNullable(impl.nextToken())
      .map(value => zio.aws.forecast.model.primitives.NextToken(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.forecast.model.ListDatasetImportJobsResponse
  ): zio.aws.forecast.model.ListDatasetImportJobsResponse.ReadOnly =
    new Wrapper(impl)
}
